diff --git a/test/freeflow/ransnc/CMakeLists.txt b/test/freeflow/ransnc/CMakeLists.txt
index 8cc866b9234416bcbcf0e88c1c9e52b7fed3e818..f8d603ee4ff195e84b3639dbb8af949c160cc52e 100644
--- a/test/freeflow/ransnc/CMakeLists.txt
+++ b/test/freeflow/ransnc/CMakeLists.txt
@@ -1,33 +1,33 @@
 add_input_file_links()
 
-dune_add_test(NAME test_channel_zeroeq2c
-              SOURCES test_channel.cc
+dune_add_test(NAME test_flatplate_zeroeq2c
+              SOURCES test_flatplate.cc
               CMAKE_GUARD HAVE_UMFPACK
               COMMAND ${CMAKE_SOURCE_DIR}/bin/testing/runtest.py
               CMD_ARGS       --script fuzzy
-                             --files ${CMAKE_SOURCE_DIR}/test/references/test_channel_zeroeq2c.vtu
-                                     ${CMAKE_CURRENT_BINARY_DIR}/test_channel2c-00031.vtu
-                             --command "${CMAKE_CURRENT_BINARY_DIR}/test_channel_zeroeq2c test_channel2c.input")
+                             --files ${CMAKE_SOURCE_DIR}/test/references/test_flatplate_zeroeq2c.vtu
+                                     ${CMAKE_CURRENT_BINARY_DIR}/test_flatplate2c-00031.vtu
+                             --command "${CMAKE_CURRENT_BINARY_DIR}/test_flatplate_zeroeq2c test_flatplate2c.input")
 
-dune_add_test(NAME test_channel_zeroeq2cni
-              SOURCES test_channel.cc
+dune_add_test(NAME test_flatplate_zeroeq2cni
+              SOURCES test_flatplate.cc
               CMAKE_GUARD HAVE_UMFPACK
               COMMAND ${CMAKE_SOURCE_DIR}/bin/testing/runtest.py
               CMD_ARGS       --script fuzzy
-                             --files ${CMAKE_SOURCE_DIR}/test/references/test_channel_zeroeq2cni.vtu
-                                     ${CMAKE_CURRENT_BINARY_DIR}/test_channel2cni-00034.vtu
-                             --command "${CMAKE_CURRENT_BINARY_DIR}/test_channel_zeroeq2cni test_channel2cni.input")
-target_compile_definitions(test_channel_zeroeq2cni PUBLIC "NONISOTHERMAL=1")
+                             --files ${CMAKE_SOURCE_DIR}/test/references/test_flatplate_zeroeq2cni.vtu
+                                     ${CMAKE_CURRENT_BINARY_DIR}/test_flatplate2cni-00034.vtu
+                             --command "${CMAKE_CURRENT_BINARY_DIR}/test_flatplate_zeroeq2cni test_flatplate2cni.input")
+target_compile_definitions(test_flatplate_zeroeq2cni PUBLIC "NONISOTHERMAL=1")
 
-add_executable(test_channel_lowrekepsilon2c EXCLUDE_FROM_ALL test_channel.cc)
-target_compile_definitions(test_channel_lowrekepsilon2c PUBLIC "LOWREKEPSILON=1")
+add_executable(test_flatplate_lowrekepsilon2c EXCLUDE_FROM_ALL test_flatplate.cc)
+target_compile_definitions(test_flatplate_lowrekepsilon2c PUBLIC "LOWREKEPSILON=1")
 
-dune_add_test(NAME test_channel_lowrekepsilon2cni
-              SOURCES test_channel.cc
+dune_add_test(NAME test_flatplate_lowrekepsilon2cni
+              SOURCES test_flatplate.cc
               CMAKE_GUARD HAVE_UMFPACK
               COMMAND ${CMAKE_SOURCE_DIR}/bin/testing/runtest.py
               CMD_ARGS       --script fuzzy
-                             --files ${CMAKE_SOURCE_DIR}/test/references/test_channel_lowrekepsilon2cni.vtu
-                                     ${CMAKE_CURRENT_BINARY_DIR}/test_channel2cni-00041.vtu
-                             --command "${CMAKE_CURRENT_BINARY_DIR}/test_channel_lowrekepsilon2cni test_channel2cni.input")
-target_compile_definitions(test_channel_lowrekepsilon2cni PUBLIC "LOWREKEPSILON=1" "NONISOTHERMAL=1")
+                             --files ${CMAKE_SOURCE_DIR}/test/references/test_flatplate_lowrekepsilon2cni.vtu
+                                     ${CMAKE_CURRENT_BINARY_DIR}/test_flatplate2cni-00041.vtu
+                             --command "${CMAKE_CURRENT_BINARY_DIR}/test_flatplate_lowrekepsilon2cni test_flatplate2cni.input")
+target_compile_definitions(test_flatplate_lowrekepsilon2cni PUBLIC "LOWREKEPSILON=1" "NONISOTHERMAL=1")
diff --git a/test/freeflow/ransnc/test_channel.cc b/test/freeflow/ransnc/test_flatplate.cc
similarity index 98%
rename from test/freeflow/ransnc/test_channel.cc
rename to test/freeflow/ransnc/test_flatplate.cc
index 2d38f3d3cf885de6f6c4812a1cb3a9e27374f6cc..b142cf6af862cc807e779a0d9343da6ed5922a67 100644
--- a/test/freeflow/ransnc/test_channel.cc
+++ b/test/freeflow/ransnc/test_flatplate.cc
@@ -19,7 +19,7 @@
 /*!
  * \file
  *
- * \brief Test for the staggered grid multi-component (Navier-)Stokes model
+ * \brief Test for the staggered grid multi-component RANS model
  */
 #include <config.h>
 
@@ -34,7 +34,7 @@
 #include <dune/grid/io/file/vtk.hh>
 #include <dune/istl/io.hh>
 
-#include "channeltestproblem.hh"
+#include "flatplatetestproblem.hh"
 
 #include <dumux/common/properties.hh>
 #include <dumux/common/parameters.hh>
@@ -78,7 +78,7 @@ int main(int argc, char** argv) try
     using namespace Dumux;
 
     // define the type tag for this problem
-    using TypeTag = TTAG(ChannelNCTestTypeTag);
+    using TypeTag = TTAG(FlatPlateNCTestTypeTag);
 
     // initialize MPI, finalize is done automatically on exit
     const auto& mpiHelper = Dune::MPIHelper::instance(argc, argv);
diff --git a/test/freeflow/ransnc/test_channel2c.input b/test/freeflow/ransnc/test_flatplate2c.input
similarity index 87%
rename from test/freeflow/ransnc/test_channel2c.input
rename to test/freeflow/ransnc/test_flatplate2c.input
index c1f9cf4758d5669095dd6bb89758db548423b310..0098301d0693d90cb8bcf3fdc05ce13d2d3fef9d 100644
--- a/test/freeflow/ransnc/test_channel2c.input
+++ b/test/freeflow/ransnc/test_flatplate2c.input
@@ -11,7 +11,7 @@ Cells1 = 20
 Grading1 = 1.4
 
 [Problem]
-Name = test_channel2c # name passed to the output routines
+Name = test_flatplate2c # name passed to the output routines
 InletVelocity = 0.1 # [m/s]
 EnableGravity = false
 
diff --git a/test/freeflow/ransnc/test_channel2cni.input b/test/freeflow/ransnc/test_flatplate2cni.input
similarity index 86%
rename from test/freeflow/ransnc/test_channel2cni.input
rename to test/freeflow/ransnc/test_flatplate2cni.input
index 949a5c47b55f6980b9128123187ca69e489fcad5..d3640ff2e28f0fff9c953e1fbe598a44926d5594 100644
--- a/test/freeflow/ransnc/test_channel2cni.input
+++ b/test/freeflow/ransnc/test_flatplate2cni.input
@@ -11,7 +11,7 @@ Cells1 = 20
 Grading1 = 1.4
 
 [Problem]
-Name = test_channel2cni # name passed to the output routines
+Name = test_flatplate2cni # name passed to the output routines
 InletVelocity = 0.1 # [m/s]
 EnableGravity = false
 
diff --git a/test/freeflow/ransnc/channeltestproblem.hh b/test/freeflow/ransnc/flatplatetestproblem.hh
similarity index 88%
rename from test/freeflow/ransnc/channeltestproblem.hh
rename to test/freeflow/ransnc/flatplatetestproblem.hh
index ed6ca552c60229fa6c3c3387e506cc31b00f218f..1ec575cf50e60b0887cca07702e62e064d606ab2 100644
--- a/test/freeflow/ransnc/channeltestproblem.hh
+++ b/test/freeflow/ransnc/flatplatetestproblem.hh
@@ -19,7 +19,7 @@
 /*!
  * \file
  * \ingroup RANSNCTests
  * \brief Channel flow test for the multi-component staggered grid Reynolds-averaged Navier-Stokes model
  */
 #ifndef DUMUX_RANS_NC_TEST_PROBLEM_HH
 #define DUMUX_RANS_NC_TEST_PROBLEM_HH
@@ -39,68 +39,68 @@
 namespace Dumux
 {
 template <class TypeTag>
-class ChannelNCTestProblem;
+class FlatPlateNCTestProblem;
 
 namespace Properties
 {
 
 #if NONISOTHERMAL
   #if LOWREKEPSILON
-  NEW_TYPE_TAG(ChannelNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, LowReKEpsilonNCNI));
+  NEW_TYPE_TAG(FlatPlateNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, LowReKEpsilonNCNI));
   #else
-  NEW_TYPE_TAG(ChannelNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, ZeroEqNCNI));
+  NEW_TYPE_TAG(FlatPlateNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, ZeroEqNCNI));
   #endif
 #else
   #if LOWREKEPSILON
-  NEW_TYPE_TAG(ChannelNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, LowReKEpsilonNC));
+  NEW_TYPE_TAG(FlatPlateNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, LowReKEpsilonNC));
   #else
-  NEW_TYPE_TAG(ChannelNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, ZeroEqNC));
+  NEW_TYPE_TAG(FlatPlateNCTestTypeTag, INHERITS_FROM(StaggeredFreeFlowModel, ZeroEqNC));
   #endif
 #endif
 
 NEW_PROP_TAG(FluidSystem);
 
 // Select the fluid system
-SET_TYPE_PROP(ChannelNCTestTypeTag, FluidSystem,
+SET_TYPE_PROP(FlatPlateNCTestTypeTag, FluidSystem,
               FluidSystems::H2OAir<typename GET_PROP_TYPE(TypeTag, Scalar)>);
 
-SET_INT_PROP(ChannelNCTestTypeTag, PhaseIdx,
+SET_INT_PROP(FlatPlateNCTestTypeTag, PhaseIdx,
              GET_PROP_TYPE(TypeTag, FluidSystem)::phase1Idx);
 
-SET_INT_PROP(ChannelNCTestTypeTag, ReplaceCompEqIdx, GET_PROP_VALUE(TypeTag, PhaseIdx));
+SET_INT_PROP(FlatPlateNCTestTypeTag, ReplaceCompEqIdx, GET_PROP_VALUE(TypeTag, PhaseIdx));
 
 // Set the grid type
-SET_TYPE_PROP(ChannelNCTestTypeTag, Grid,
+SET_TYPE_PROP(FlatPlateNCTestTypeTag, Grid,
               Dune::YaspGrid<2, Dune::TensorProductCoordinates<typename GET_PROP_TYPE(TypeTag, Scalar), 2> >);
 
 // Set the problem property
-SET_TYPE_PROP(ChannelNCTestTypeTag, Problem, Dumux::ChannelNCTestProblem<TypeTag> );
+SET_TYPE_PROP(FlatPlateNCTestTypeTag, Problem, Dumux::FlatPlateNCTestProblem<TypeTag> );
 
-SET_BOOL_PROP(ChannelNCTestTypeTag, EnableFVGridGeometryCache, true);
+SET_BOOL_PROP(FlatPlateNCTestTypeTag, EnableFVGridGeometryCache, true);
 
-SET_BOOL_PROP(ChannelNCTestTypeTag, EnableGridFluxVariablesCache, true);
-SET_BOOL_PROP(ChannelNCTestTypeTag, EnableGridVolumeVariablesCache, true);
+SET_BOOL_PROP(FlatPlateNCTestTypeTag, EnableGridFluxVariablesCache, true);
+SET_BOOL_PROP(FlatPlateNCTestTypeTag, EnableGridVolumeVariablesCache, true);
 
 // Enable gravity
-SET_BOOL_PROP(ChannelNCTestTypeTag, UseMoles, true);
+SET_BOOL_PROP(FlatPlateNCTestTypeTag, UseMoles, true);
 } // end namespace Properties
 
 /*!
  * \ingroup RANSNCTests
  * \brief  Test problem for the one-phase model.
  *
- * Dry air is entering the channel, in 2-D a flat plate, from the left side.
+ * Dry air is entering from the left side and flows above a 1-D a flat plate.
  * In the middle of the inlet, water vapor is injected, which spreads by turbulent diffusion.
  * For the nonisothermal model the bottom has a constant temperature
  * which is \f$ \unit[30]{K} \f$ higher than the initial and inlet temperature.
  */
 template <class TypeTag>
 #if LOWREKEPSILON
-class ChannelNCTestProblem : public LowReKEpsilonProblem<TypeTag>
+class FlatPlateNCTestProblem : public LowReKEpsilonProblem<TypeTag>
 {
     using ParentType = LowReKEpsilonProblem<TypeTag>;
 #else
-class ChannelNCTestProblem : public ZeroEqProblem<TypeTag>
+class FlatPlateNCTestProblem : public ZeroEqProblem<TypeTag>
 {
     using ParentType = ZeroEqProblem<TypeTag>;
 #endif
@@ -123,7 +123,7 @@ class ChannelNCTestProblem : public ZeroEqProblem<TypeTag>
     static const unsigned int phaseIdx = GET_PROP_VALUE(TypeTag, PhaseIdx);
 
 public:
-    ChannelNCTestProblem(std::shared_ptr<const FVGridGeometry> fvGridGeometry)
+    FlatPlateNCTestProblem(std::shared_ptr<const FVGridGeometry> fvGridGeometry)
     : ParentType(fvGridGeometry), eps_(1e-6)
     {
         inletVelocity_ = getParam<Scalar>("Problem.InletVelocity");
@@ -19,7 +19,7 @@
  * \file
  * \ingroup RANSNCTests
- * \brief Channel flow test for the multi-component staggered grid Reynolds-averaged Navier-Stokes model
+ * \brief Flat plate test for the multi-component staggered grid Reynolds-averaged Navier-Stokes model
  */
 #ifndef DUMUX_RANS_NC_TEST_PROBLEM_HH
diff --git a/test/references/test_channel_lowrekepsilon2cni.vtu b/test/references/test_flatplate_lowrekepsilon2cni.vtu
similarity index 100%
rename from test/references/test_channel_lowrekepsilon2cni.vtu
rename to test/references/test_flatplate_lowrekepsilon2cni.vtu
diff --git a/test/references/test_channel_zeroeq2c.vtu b/test/references/test_flatplate_zeroeq2c.vtu
similarity index 100%
rename from test/references/test_channel_zeroeq2c.vtu
rename to test/references/test_flatplate_zeroeq2c.vtu
diff --git a/test/references/test_channel_zeroeq2cni.vtu b/test/references/test_flatplate_zeroeq2cni.vtu
similarity index 100%
rename from test/references/test_channel_zeroeq2cni.vtu
rename to test/references/test_flatplate_zeroeq2cni.vtu